colour_hdri.calibration.debevec1997 Module — Colour - HDRI 0.1.0 documentation

# colour_hdri.calibration.debevec1997 Module

## Debevec (1997) Camera Response Function Computation

Defines Debevec (1997) camera responses computation objects:

- `g_solve()`
- `camera_response_functions_Debevec1997()`

See also

Colour - HDRI - Example: Merge from Low Dynamic Range Files IPython Notebook

References

[1] | Debevec, P., & Malik, J. (1997). Recovering High Dynamic Range Radiance Maps from Photographs, (August), 1–10. doi:10.1145/258734.258884

`colour_hdri.calibration.debevec1997.` `g_solve`(Z, B, l=30, w=<function weighting_function_Debevec1997 at 0x10ae70f50>, n=256)

  Given a set of pixel values observed for several pixels in several images with different exposure times, this function returns the imaging system’s response function \(g\) as well as the log film irradiance values \(lE\) for the observed pixels.

  Parameters: | Z (array_like) – Set of pixel values observed for several pixels in several images. B (array_like) – Log \(\Delta t\), or log shutter speed for images. l (numeric, optional) – \(\lambda\) smoothing term. w (callable, optional) – Weighting function \(w\). n (int, optional) – \(n\) constant.
  Returns: | Camera response functions \(g(z)\) and log film irradiance values \(lE\).
  Return type: | tuple

`colour_hdri.calibration.debevec1997.` `camera_response_functions_Debevec1997`(image_stack, s=<function samples_Grossberg2003 at 0x10ae70de8>, samples=1000, l=30, w=<function weighting_function_Debevec1997 at 0x10ae70f50>, n=256, normalise=True)

  Returns the camera response functions for given image stack using Debevec (1997) method.

  Image channels are sampled with \(s\) sampling function and the output samples are passed to `g_solve()`.

  Parameters: | image_stack (ImageStack) – Stack of single channel or multi-channel floating point images. s (callable, optional) – Sampling function \(s\). samples (int, optional) – Samples count per images. l (numeric, optional) – \(\lambda\) smoothing term. w (callable, optional) – Weighting function \(w\). n (int, optional) – \(n\) constant. normalise (bool, optional) – Enables the camera response functions normalisation. Uncertain camera response functions values resulting from \(w\) function are set to zero.
  Returns: | Camera response functions \(g(z)\).
  Return type: | ndarray